@@ -23,7 +23,9 @@ def _port_regex():
 @lru_cache
 def _simple_hostname_regex():
     """Simple hostname validation regex."""
-    return re.compile(r"^[a-zA-Z0-9][a-zA-Z0-9-]{0,61}[a-zA-Z0-9]$")
+    # {0,59} because two characters are already matched at
+    # the beginning and at the end, making the range {1, 61}
+    return re.compile(r"^(?!-)[a-z0-9](?:[a-z0-9-]{0,59}[a-z0-9])?(?<!-)$", re.IGNORECASE)
 
 
 def _port_validator(value: str):
@@ -98,12 +100,8 @@ def hostname(
             Ref: [RFC 2782](https://www.rfc-editor.org/rfc/rfc2782).
 
     Returns:
-        (Literal[True]):
-            If `value` is a valid hostname.
-        (ValidationError):
-            If `value` is an invalid hostname.
-
-    > *New in version 0.21.0*.
+        (Literal[True]): If `value` is a valid hostname.
+        (ValidationError): If `value` is an invalid hostname.
     """
     if not value:
         return False
