@@ -13,10 +13,12 @@ from .utils import validator
 @lru_cache
 def _username_regex():
     return re.compile(
+        # extended latin
+        r"(^[\u0100-\u017F\u0180-\u024F]"
         # dot-atom
-        r"(^[-!#$%&'*+/=?^_`{}|~0-9A-Z]+(\.[-!#$%&'*+/=?^_`{}|~0-9A-Z]+)*$"
+        + r"|[-!#$%&'*+/=?^_`{}|~0-9a-z]+(\.[-!#$%&'*+/=?^_`{}|~0-9a-z]+)*$"
         # non-quoted-string
-        + r"|^([\001-\010\013\014\016-\037!#-\[\]-\177]|\\[\001-\011\013\014\016-\177])*$)",
+        + r"|^([\001-\010\013\014\016-\037!#-\[\]-\177]|\\[\011.])*$)",
         re.IGNORECASE,
     )
 
@@ -25,7 +27,7 @@ def _username_regex():
 def _path_regex():
     return re.compile(
         # allowed symbols
-        r"^[\/a-zA-Z0-9\-\.\_\~\!\$\&\'\(\)\*\+\,\;\=\:\@\%"
+        r"^[\/a-z0-9\-\.\_\~\!\$\&\'\(\)\*\+\,\;\=\:\@\%"
         # emoticons / emoji
         + r"\U0001F600-\U0001F64F"
         # multilingual unicode ranges
@@ -38,7 +40,14 @@ def _validate_scheme(value: str):
     """Validate scheme."""
     # More schemes will be considered later.
     return (
-        value in {"ftp", "ftps", "git", "http", "https", "rtsp", "sftp", "ssh", "telnet"}
+        value
+        # fmt: off
+        in {
+            "ftp", "ftps", "git", "http", "https",
+            "rtmp", "rtmps", "rtsp", "sftp",
+            "ssh", "telnet",
+        }
+        # fmt: on
         if value
         else False
     )
@@ -112,11 +121,23 @@ def _validate_optionals(path: str, query: str, fragment: str, strict_query: bool
     optional_segments = True
     if path:
         optional_segments &= bool(_path_regex().match(path))
-    if query and parse_qs(query, strict_parsing=strict_query):
-        optional_segments &= True
+    try:
+        if (
+            query
+            # ref: https://github.com/python/cpython/issues/117109
+            and parse_qs(query, strict_parsing=strict_query, separator="&")
+            and parse_qs(query, strict_parsing=strict_query, separator=";")
+        ):
+            optional_segments &= True
+    except TypeError:
+        # for Python < v3.9.2 (official v3.10)
+        if query and parse_qs(query, strict_parsing=strict_query):
+            optional_segments &= True
     if fragment:
         # See RFC3986 Section 3.5 Fragment for allowed characters
-        optional_segments &= bool(re.fullmatch(r"[0-9a-zA-Z?/:@\-._~%!$&'()*+,;=]*", fragment))
+        optional_segments &= bool(
+            re.fullmatch(r"[0-9a-z?/:@\-._~%!$&'()*+,;=]*", fragment, re.IGNORECASE)
+        )
     return optional_segments
 
 
